@@ -2,5 +2,5 @@
 import warnings
 warnings.simplefilter(action='ignore', category=FutureWarning)
 
-from . import rapa
+from . import Project
 from . import version
\ No newline at end of file
