@@ -46,12 +46,9 @@ class RAPABase():
     * target_type = None # Set at initialization
     * project = None # Set at initialization or with 'perform_parsimony()'"""
 
-    def __init__(self, project: Union[dr.Project, str] = None):
+    def __init__(self):
         if self.__class__.__name__ == "RAPABase":
             raise RuntimeError("Do not instantiate the RAPABase class directly; use RAPAClassif or RAPARegress")
-        self._classification = None
-        self.target_type = None
-        self.project = None
 
     @staticmethod
     def _wait_for_jobs(project: dr.Project, progress_bar: bool = True, sleep_time: int = 5, pbar = None, pbar_prefix: str = '', job_type: str = '', timeout = 21600):
@@ -364,6 +361,11 @@ class RAPABase():
                 The random number generator seed for DataRobot. Use this parameter to make sure
                 that DataRobot will give you the same results each time you run it on the
                 same input data set with that seed.
+            
+        :Returns:
+        ------------
+            datarobot.Project
+                The DataRobot project submitted
 
         """
         # TODO: provide an option for columns to disregard
@@ -377,7 +379,7 @@ class RAPABase():
 
         project = dr.Project.create(sourcedata=input_data_df, project_name=project_name)
 
-        project.set_target(target=target_name, target_type=target_type,
+        project.analyze_and_model(target=target_name, target_type=target_type,
                         worker_count=worker_count, mode=mode, metric=metric,
                         advanced_options=dr.AdvancedOptions(seed=random_state, accuracy_optimized_mb=False,
                                                             prepare_model_for_deployment=False, blend_best_models=False),
@@ -441,13 +443,13 @@ class RAPABase():
                 Similar to datarobot's Feature Importance Rank Ensembling for advanced feature selection (FIRE) package's 'lifes' 
                 https://www.datarobot.com/blog/using-feature-importance-rank-ensembling-fire-for-advanced-feature-selection/ 
             
-            cv_mean_error_limit: float, optional (default = None)
+            cv_average_mean_error_limit: float, optional (default = None)
                 The limit of cross validation mean error to help avoid overfitting. By default, the limit is off, 
                 and the each 'feature_range' will be ran. Limit exists only if supplied a number >= 0.0
 
                 Ex: 'feature_range' = 2.5, feature_range = [100, 90, 80, 50]
                     RAPA finds that the average AUC for each CV fold is [.8, .6, .9, .5] respectfully,
-                    the mean of these is 0.7. The average error is += 0.15. If 0.15 >= cv_mean_error_limit,
+                    the mean of these is 0.7. The average error is += 0.15. If 0.15 >= cv_average_mean_error_limit,
                     the training stops.
             
             feature_impact_metric: str, optional (default = 'median')
@@ -472,6 +474,13 @@ class RAPABase():
 
                 When None, the metric is determined by what class inherits from base. For instance,
                 a `RAPAClassif` instance's default is 'AUC', and `RAPARegress` is 'R Squared'
+            
+            verbose: bool, optional (default = True)
+                If True, prints updates from DataRobot and rapa during parsimonious feature rduction
+        
+        :Returns:
+        ------------
+            None
         """ 
         # TODO: return a dictionary of values? {"time_taken": 2123, "cv_mean_error": list[floats], ""}
         # TODO: graph cv performance boxplots
@@ -501,10 +510,7 @@ class RAPABase():
                 raise Exception(f'Could not find the project.')
         
         # get starting featurelist
-        try:
-            starting_featurelist = utils.get_featurelist(starting_featurelist_name, project)
-        except: # TODO: flesh out exceptions
-            tqdm.write("Something went wrong getting the starting featurelist...")
+        starting_featurelist = utils.get_featurelist(starting_featurelist_name, project)
 
         # check feature_range size
         if len(feature_range) == 0:
@@ -713,7 +719,7 @@ class RAPABase():
                                                                         previous_best_model=previous_best_model, 
                                                                         featurelist_prefix=featurelist_prefix, 
                                                                         metric=metric,
-                                                                        verbose=True)
+                                                                        verbose=verbose)
                     tqdm.write(f'Checking lives: {time.time()-temp_start:.{config.TIME_DECIMALS}f}s')
                     if lives < 0:
                         current_best_model_score = mean(previous_best_model.get_cross_validation_scores()['cvScores'][metric].values())
